@@ -109,19 +109,17 @@ def find_new_files(args, path: Path) -> List[str]:
     scanned_set = set(scanned_files)
 
     try:
-        existing_set = set(
-            [
-                d["path"]
-                for d in args.db.query(
-                    f"""select path from media
+        existing_set = {
+            d["path"]
+            for d in args.db.query(
+                f"""select path from media
                 where 1=1
                     and time_deleted=0
                     and path like '{path}%'
                     {'AND time_downloaded > 0' if 'time_downloaded' in columns else ''}
                 """
-                )
-            ]
-        )
+            )
+        }
     except Exception as e:
         log.debug(e)
         new_files = list(scanned_set)
