@@ -148,6 +148,10 @@ def mv_to_keep_folder(args, media_file: str) -> None:
 
     keep_path.mkdir(exist_ok=True)
     new_path = shutil.move(media_file, keep_path)
+    if args.keep_cmd:
+        import shlex
+
+        utils.cmd_detach(shlex.split(args.keep_cmd), new_path)
     with args.db.conn:
         args.db.conn.execute("UPDATE media set path = ? where path = ?", [new_path, media_file])
 
@@ -431,7 +435,7 @@ def socket_play(args, m: dict) -> None:
         play_opts += ",script-opts=ytdl_hook-try_ytdl_first=yes"
 
     f = m["path"].replace("\\", "\\\\").replace('"', '\\"').replace("\n", "\\n")
-    args.sock.send((f'raw loadfile "{f}" replace "{play_opts}" \n').encode("utf-8"))
+    args.sock.send((f'raw loadfile "{f}" replace "{play_opts}" \n').encode())
     sleep(args.interdimensional_cable)
 
 
