@@ -52,13 +52,15 @@ def with_timeout(timeout):
 
 
 def os_bg_kwargs() -> dict:
+    # prevent ctrl-c from affecting subprocesses first
+
     if hasattr(os, "setpgrp"):
-        os_kwargs = dict(start_new_session=True)
+        return dict(start_new_session=True)
     else:
-        CREATE_NEW_PROCESS_GROUP = 0x00000200
-        DETACHED_PROCESS = 0x00000008
-        os_kwargs = dict(creationflags=DETACHED_PROCESS | CREATE_NEW_PROCESS_GROUP)
-    return os_kwargs
+        # CREATE_NEW_PROCESS_GROUP = 0x00000200
+        # DETACHED_PROCESS = 0x00000008
+        # os_kwargs = dict(creationflags=DETACHED_PROCESS | CREATE_NEW_PROCESS_GROUP)
+        return {}
 
 
 def run_once(f):
@@ -138,7 +140,7 @@ def sanitize_url(args, path: str) -> str:
     return path
 
 
-def cmd(*command, strict=True, cwd=None, quiet=True, interactive=False, **kwargs) -> subprocess.CompletedProcess:
+def cmd(*command, strict=True, cwd=None, quiet=True, **kwargs) -> subprocess.CompletedProcess:
     EXP_FILTER = re.compile(
         "|".join(
             [
@@ -165,11 +167,7 @@ def cmd(*command, strict=True, cwd=None, quiet=True, interactive=False, **kwargs
             print(s)
         return s
 
-    if len(command) == 1 and kwargs.get("shell") is True:
-        command = command[0]
-
-    os_kwargs = {} if interactive else os_bg_kwargs()
-    r = subprocess.run(command, capture_output=True, text=True, cwd=cwd, **os_kwargs, **kwargs)
+    r = subprocess.run(command, capture_output=True, text=True, cwd=cwd, **os_bg_kwargs(), **kwargs)
 
     log.debug(r.args)
     r.stdout = print_std(r.stdout)
@@ -182,6 +180,44 @@ def cmd(*command, strict=True, cwd=None, quiet=True, interactive=False, **kwargs
     return r
 
 
+def cmd_detach(*command, **kwargs) -> subprocess.CompletedProcess:
+    # https://stackoverflow.com/questions/62521658/python-subprocess-detach-a-process
+    # if using with ffmpeg remember to run with `-nostdin`
+    stdout = os.open(os.devnull, os.O_WRONLY)
+    stderr = os.open(os.devnull, os.O_WRONLY)
+    stdin = os.open(os.devnull, os.O_RDONLY)
+
+    command = conform(command)
+    if command[0] in ["fish", "bash"]:
+        import shlex
+
+        command = command[0:2] + [shlex.join(command[2:])]
+    subprocess.Popen(command, stdin=stdin, stdout=stdout, stderr=stderr, close_fds=True, **os_bg_kwargs(), **kwargs)
+    return subprocess.CompletedProcess(command, 0, "Detached command is async")
+
+
+def cmd_interactive(*command) -> subprocess.CompletedProcess:
+    return_code = os.spawnvpe(os.P_WAIT, command[0], command, os.environ)
+    return subprocess.CompletedProcess(command, return_code)
+
+
+def Pclose(process) -> subprocess.CompletedProcess:
+    try:
+        stdout, stderr = process.communicate(input)
+    except subprocess.TimeoutExpired as exc:
+        process.kill()
+        if platform.system() == "Windows":
+            exc.stdout, exc.stderr = process.communicate()
+        else:
+            process.wait()
+        raise
+    except Exception:
+        process.kill()
+        raise
+    return_code = process.poll()
+    return subprocess.CompletedProcess(process.args, return_code, stdout, stderr)
+
+
 def file_temp_copy(src):
     fo_dest = tempfile.NamedTemporaryFile(delete=False)
     with open(src, "r+b") as fo_src:
@@ -294,28 +330,6 @@ def list_dict_filter_bool(media: List[dict], keep_0=True) -> List[dict]:
     return [d for d in [dict_filter_bool(d, keep_0) for d in media] if d]
 
 
-def cmd_interactive(*command) -> subprocess.CompletedProcess:
-    return_code = os.spawnvpe(os.P_WAIT, command[0], command, os.environ)
-    return subprocess.CompletedProcess(command, return_code)
-
-
-def Pclose(process) -> subprocess.CompletedProcess:
-    try:
-        stdout, stderr = process.communicate(input)
-    except subprocess.TimeoutExpired as exc:
-        process.kill()
-        if platform.system() == "Windows":
-            exc.stdout, exc.stderr = process.communicate()
-        else:
-            process.wait()
-        raise
-    except Exception:
-        process.kill()
-        raise
-    return_code = process.poll()
-    return subprocess.CompletedProcess(process.args, return_code, stdout, stderr)
-
-
 def chunks(lst, n) -> Generator:
     for i in range(0, len(lst), n):
         yield lst[i : i + n]
@@ -340,8 +354,8 @@ def combine(*list_) -> Optional[str]:
     if not list_:
         return None
 
-    no_comma = sum([str(s).split(",") for s in list_], [])
-    no_semicolon = sum([s.split(";") for s in no_comma], [])
+    no_comma = sum((str(s).split(",") for s in list_), [])
+    no_semicolon = sum((s.split(";") for s in no_comma), [])
     no_double_space = [_RE_COMBINE_WHITESPACE.sub(" ", s).strip() for s in no_semicolon]
     no_unknown = [x for x in no_double_space if x.lower() not in ("unknown", "none", "und", "")]
 
@@ -440,7 +454,7 @@ class argparse_enum(argparse.Action):
         # Generate choices from the Enum
         kwargs.setdefault("choices", tuple(e.value for e in enum_type))
 
-        super(argparse_enum, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self._enum = enum_type
 
